@@ -245,6 +245,8 @@ class Surface(object):
             width (int): The thickness of the line in pixels. Defaults to 1.
             color (tuple or str): The color (r, g, b) or color name.
         """
+        if start_xy == end_xy:
+            return
 
         # antialiased thick lines aren't supported by pygame, and the aaline function has some
         # strange bugs on OS X (line comes out the wrong colors, see
@@ -404,6 +406,10 @@ class Screen(Surface):
         super(Screen, self).rectangle(*args, **kwargs)
         self.needs_update = True
 
+    def line(self, *args, **kwargs):
+        super(Screen, self).line(*args, **kwargs)
+        self.needs_update = True
+
     def image(self, *args, **kwargs):
         super(Screen, self).image(*args, **kwargs)
         self.needs_update = True
